@@ -1,5 +1,4 @@
 import pathlib
-from enum import Enum
 
 
 PROFILE_FILENAME = ".neosctl"
@@ -7,7 +6,3 @@ PROFILE_FILEPATH = pathlib.Path().home() / PROFILE_FILENAME
 
 
 DEFAULT_PROFILE = "default"
-
-
-class AuthFlow(Enum):
-    keycloak = "keycloak"
