@@ -398,3 +398,57 @@ def product_field_description(
     r = _request(ctx)
 
     process_response(r)
+
+
+@product_app.command("quality-expectations")
+def product_quality_expectations(
+    ctx: typer.Context,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+):
+    """Get data product quality expectations.
+    """
+    @ensure_login
+    def _request(ctx: typer.Context) -> httpx.Response:
+        return util.get(
+            ctx,
+            metadata_url(ctx, "/product/{}/quality/expectations".format(product_name)),
+        )
+    r = _request(ctx)
+
+    process_response(r)
+
+
+@product_app.command("quality-profiling")
+def product_quality_profiling(
+    ctx: typer.Context,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+):
+    """Get data product quality profiling.
+    """
+    @ensure_login
+    def _request(ctx: typer.Context) -> httpx.Response:
+        return util.get(
+            ctx,
+            metadata_url(ctx, "/product/{}/quality/profiling".format(product_name)),
+        )
+    r = _request(ctx)
+
+    process_response(r)
+
+
+@product_app.command("quality-validations")
+def product_quality_validations(
+    ctx: typer.Context,
+    product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
+):
+    """Get data product quality validations.
+    """
+    @ensure_login
+    def _request(ctx: typer.Context) -> httpx.Response:
+        return util.get(
+            ctx,
+            metadata_url(ctx, "/product/{}/quality/validations".format(product_name)),
+        )
+    r = _request(ctx)
+
+    process_response(r)
