@@ -48,6 +48,7 @@ class OptionalProfile(BaseModel):
     gateway_api_url: str = ""
     registry_api_url: str = ""
     iam_api_url: str = ""
+    storage_api_url: str = ""
     user: str = ""
     access_token: str = ""
     refresh_token: str = ""
@@ -58,6 +59,7 @@ class Profile(BaseModel):
     gateway_api_url: str
     registry_api_url: str
     iam_api_url: str
+    storage_api_url: str
     user: str
     access_token: str
     refresh_token: str
@@ -100,6 +102,7 @@ class Common:
     gateway_api_url: str
     registry_api_url: str
     iam_api_url: str
+    storage_api_url: str
     profile_name: str
     config: configparser.ConfigParser
     profile: Optional[Profile]
@@ -123,7 +126,15 @@ class Common:
     def get_iam_api_url(self):
         url = None
         if self.iam_api_url:
-            url = self.registry_api_url
+            url = self.iam_api_url
         if self.profile and self.profile.iam_api_url:
             url = self.profile.iam_api_url
         return url
+
+    def get_storage_api_url(self):
+        url = None
+        if self.storage_api_url:
+            url = self.storage_api_url
+        if self.profile and self.profile.storage_api_url:
+            url = self.profile.storage_api_url
+        return url
